@@ -46,7 +46,15 @@ class Browser(webdriver.Chrome):
         __shadow_root = __browser.execute_script('return arguments[0].shadowRoot', element)
         return __shadow_root
 
-
+        # setting up the browser
+        __caps = DesiredCapabilities().CHROME
+        __caps["pageLoadStrategy"] = "eager"
+        # noinspection SpellCheckingInspection
+        __options = webdriver.ChromeOptions()
+        __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
+        # noinspection SpellCheckingInspection
+        __options.add_experimental_option("prefs", __chrome_preferences)
+        __options.add_argument("disable-infobars")
 
 
     session_id = ''
@@ -81,16 +89,11 @@ class Browser(webdriver.Chrome):
                     except:
                         pass
 
-        # setting up the browser
-        __caps = DesiredCapabilities().CHROME
-        __caps["pageLoadStrategy"] = "eager"
-        # noinspection SpellCheckingInspection
-        __options = webdriver.ChromeOptions()
+
         if not pictures:
-            __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
-            # noinspection SpellCheckingInspection
-            __options.add_experimental_option("prefs", __chrome_preferences)
-            __options.add_argument("disable-infobars")
+            Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
+        else:
+            Browser = webdriver.Chrome(service_args=['--silent'], desired_capabilities=self.__caps)
 
         # noinspection SpellCheckingInspection
         Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
